Learn R Programming

BivarP (version 1.0)

BivarP-package: Estimating the Parameters of Some Bivariate Distributions

Description

Parameter estimation of bivariate distribution functions modeled as a Archimedean copula function. The input data may contain values from right censored. Used marginal distributions are two-parameter. Methods for density, distribution, survival, random sample generation.

Arguments

Details

Package:
BivarP
Type:
Package
Version:
1.0
Date:
2015-04-17
License:
GPL (>= 3)

References

M. Mahfoud, "Bivariate Archimedean copulas: an application to two stock market indices", Vrije Universiteit Amsterdam, BMI Paper, Amsterdam-2012, https://www.few.vu.nl/en/Images/werkstuk-mahfoud_tcm39-277460.pdf